Precedence

Enum Precedence 

pub enum Precedence {
Show 18 variants Period, DoubleColon, AtTz, MulDivModOp, PlusMinus, Xor, Ampersand, Caret, Pipe, Colon, Between, Eq, Like, Is, PgOther, UnaryNot, And, Or,
}
Operators for which precedence must be defined.

Higher number -> higher precedence. See expression parsing for how these values are used.

Variants



Period

Member access operator . (highest precedence).



DoubleColon

Postgres style type cast ::.



AtTz

Timezone operator (e.g. AT TIME ZONE).



MulDivModOp

Multiplication / Division / Modulo operators (*, /, %).



PlusMinus

Addition / Subtraction (+, -).



Xor

Bitwise XOR operator (^).



Ampersand

Bitwise AND operator (&).



Caret

Bitwise CARET (^) for some dialects.



Pipe

Bitwise OR / pipe operator (|).



Colon

: operator for json/variant access.



Between

BETWEEN operator.



Eq

Equality operator (=).



Like

Pattern matching (LIKE).



Is

IS operator (e.g. IS NULL).



PgOther

Other Postgres-specific operators.



UnaryNot

Unary NOT.



And

Logical AND.



Or

Logical OR (lowest precedence).